=== modified file 'drizzled/table_share.h'
--- drizzled/table_share.h	2010-03-02 22:39:09 +0000
+++ drizzled/table_share.h	2010-03-08 16:58:42 +0000
@@ -206,6 +206,11 @@
   uint32_t   stored_rec_length;         /* Stored record length*/
   enum row_type row_type;		/* How rows are stored */
 
+  uint32_t getRecordLength()
+  {
+    return reclength;
+  }
+
 private:
   /* Max rows is a hint to HEAP during a create tmp table */
   uint64_t max_rows;

=== modified file 'plugin/schema_dictionary/show_temporary_tables.cc'
--- plugin/schema_dictionary/show_temporary_tables.cc	2010-03-05 22:56:46 +0000
+++ plugin/schema_dictionary/show_temporary_tables.cc	2010-03-08 16:58:42 +0000
@@ -25,15 +25,21 @@
 using namespace std;
 using namespace drizzled;
 
+ShowTemporaryTables::ShowTemporaryTables() :
+  drizzled::plugin::TableFunction("DATA_DICTIONARY", "SHOW_TEMPORARY_TABLES")
+{
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+  add_field("RECORDS", plugin::TableFunction::NUMBER);
+  add_field("RECORD_LENGTH", plugin::TableFunction::NUMBER);
+  add_field("ENGINE");
+}
+
 ShowTemporaryTables::Generator::Generator(Field **arg) :
   plugin::TableFunction::Generator(arg)
 {
   session= current_session;
   table= session->temporary_tables;
-
-  bool x= table ? true : false;
-
-  std::cerr << "Do we have any tables? " << x << "\n";
 }
 
 bool ShowTemporaryTables::Generator::populate()
@@ -56,6 +62,12 @@
   /* TABLE_NAME */
   push(table->s->table_name.str);
 
+  /* RECORDS */
+  push(static_cast<uint64_t>(table->cursor->records()));
+
+  /* RECORD_LENGTH */
+  push(static_cast<uint64_t>(table->getRecordLength()));
+
   /* ENGINE */
-  push("foo");
+  push(table->getEngine()->getName());
 }

=== modified file 'plugin/schema_dictionary/show_temporary_tables.h'
--- plugin/schema_dictionary/show_temporary_tables.h	2010-03-05 22:56:46 +0000
+++ plugin/schema_dictionary/show_temporary_tables.h	2010-03-08 16:58:42 +0000
@@ -24,13 +24,7 @@
 class ShowTemporaryTables : public drizzled::plugin::TableFunction
 {
 public:
-  ShowTemporaryTables() :
-    drizzled::plugin::TableFunction("DATA_DICTIONARY", "SHOW_TEMPORARY_TABLES")
-  {
-    add_field("TABLE_SCHEMA");
-    add_field("TABLE_NAME");
-    add_field("ENGINE");
-  }
+  ShowTemporaryTables();
 
   class Generator : public drizzled::plugin::TableFunction::Generator
   {

=== added file 'plugin/schema_dictionary/tests/r/show_temporary_tables.result'
--- plugin/schema_dictionary/tests/r/show_temporary_tables.result	1970-01-01 00:00:00 +0000
+++ plugin/schema_dictionary/tests/r/show_temporary_tables.result	2010-03-08 16:58:42 +0000
@@ -0,0 +1,36 @@
+create schema a;
+use a;
+create temporary table a (A int) ENGINE=MEMORY;
+insert into a VALUES (1), (2), (3);
+select * from data_dictionary.show_temporary_Tables;
+TABLE_SCHEMA	TABLE_NAME	RECORDS	RECORD_LENGTH	ENGINE
+a	a	0	5	MEMORY
+create schema b;
+use b;
+create temporary table a (A int);
+create temporary table b (A int);
+insert into a SELECT * FROM a.a;
+insert into b SELECT * FROM a.a;
+SELECT * FROM a;
+A
+1
+2
+3
+SELECT * FROM b;
+A
+1
+2
+3
+select * from data_dictionary.show_temporary_Tables;
+TABLE_SCHEMA	TABLE_NAME	RECORDS	RECORD_LENGTH	ENGINE
+b	b	3	5	InnoDB
+b	a	3	5	InnoDB
+a	a	3	5	MEMORY
+drop schema a;
+select * from data_dictionary.show_temporary_Tables;
+TABLE_SCHEMA	TABLE_NAME	RECORDS	RECORD_LENGTH	ENGINE
+b	b	3	5	InnoDB
+b	a	3	5	InnoDB
+drop schema b;
+select * from data_dictionary.show_temporary_Tables;
+TABLE_SCHEMA	TABLE_NAME	RECORDS	RECORD_LENGTH	ENGINE

=== added file 'plugin/schema_dictionary/tests/t/show_temporary_tables.test'
--- plugin/schema_dictionary/tests/t/show_temporary_tables.test	1970-01-01 00:00:00 +0000
+++ plugin/schema_dictionary/tests/t/show_temporary_tables.test	2010-03-08 16:58:42 +0000
@@ -0,0 +1,24 @@
+create schema a;
+use a;
+create temporary table a (A int) ENGINE=MEMORY;
+insert into a VALUES (1), (2), (3);
+select * from data_dictionary.show_temporary_Tables;
+
+create schema b;
+use b;
+create temporary table a (A int);
+create temporary table b (A int);
+
+insert into a SELECT * FROM a.a;
+insert into b SELECT * FROM a.a;
+
+SELECT * FROM a;
+SELECT * FROM b;
+
+select * from data_dictionary.show_temporary_Tables;
+
+drop schema a;
+select * from data_dictionary.show_temporary_Tables;
+
+drop schema b;
+select * from data_dictionary.show_temporary_Tables;

